@@ -1,5 +1,5 @@
 #fix for package and file name being same
-from Quandl import get
+from .Quandl import get, push, search
 __all__ =['Quandl']
 
 __author__ = 'mhartney & ChrisStevens'
